#!/bin/sh
### BEGIN INIT INFO
# Provides:          sftpcloudfs
# Required-Start:    $network $local_fs $remote_fs
# Required-Stop:     $remote_fs
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: sftpcloudfs
# Description:       SFTP interface to Rackspace Cloud Files and OpenStack Object Storage.
### END INIT INFO

# Author: Christophe Le Guern <c35sys@gmail.com>

# PATH should only include /usr
PATH=/sbin:/usr/sbin:/bin:/usr/bin
DESC=sftpcloudfs                 # Introduce a short description here
NAME=sftpcloudfs                 # Introduce the short server's name here
CONFIGFILE=/etc/sftpcloudfs/sftpcloudfs.conf # Configuration file
DAEMON=/usr/bin/sftpcloudfs      # Introduce the server's location here
LOGDIR=/var/log/${NAME}          # Logs directory
LOGFILE=${LOGDIR}/${NAME}.log    # Log file
DAEMON_ARGS="--config ${CONFIGFILE}"      # Arguments to run the daemon with
PIDDIR=/var/run/${NAME}
PIDFILE=${PIDDIR}/$NAME.pid
SCRIPTNAME=/etc/init.d/$NAME

# Exit if the package is not installed
[ -x $DAEMON ] || exit 0

# Exit if there is no configuration file
if [ ! -f ${CONFIGFILE} ]; then echo "Missing Configuration file"; exit 0; fi

# Read configuration variable file if it is present
[ -r /etc/default/$NAME ] && . /etc/default/$NAME

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.0-6) to ensure that this file is present.
. /lib/lsb/init-functions

do_start() {

	# create PID dir (/var/run/ is tmpfs)
	if [ ! -d ${PIDDIR} ] ; then
		mkdir -m 0700 -p ${PIDDIR}
		chown -R sftpcloudfs:sftpcloudfs ${PIDDIR}
	fi
	# Return
	#   0 if daemon has been started
	#   1 if daemon was already running
	#   2 if daemon could not be started
	start-stop-daemon --start --quiet --pidfile $PIDFILE --exec $DAEMON --test > /dev/null \
		|| return 1
	start-stop-daemon --start --quiet --pidfile $PIDFILE --exec $DAEMON -- \
		$DAEMON_ARGS \
		|| return 2
	# Add code here, if necessary, that waits for the process to be ready
	# to handle requests from services started subsequently which depend
	# on this one.  As a last resort, sleep for some time.
}

do_stop() {
	# Return
	#   0 if daemon has been stopped
	#   1 if daemon was already stopped
	#   2 if daemon could not be stopped
	#   other if a failure occurred
	start-stop-daemon --stop --quiet --retry=TERM/30/KILL/5 --pidfile $PIDFILE --name $(basename $DAEMON)
	RETVAL="$?"
	[ "$RETVAL" = 2 ] && return 2
	# Wait for children to finish too if this is a daemon that forks
	# and if the daemon is only ever run from this initscript.
	# If the above conditions are not satisfied then add some other code
	# that waits for the process to drop all resources that could be
	# needed by services started subsequently.  A last resort is to
	# sleep for some time.
	start-stop-daemon --stop --quiet --oknodo --retry=0/30/KILL/5 --exec $DAEMON
	[ "$?" = 2 ] && return 2
	# Many daemons don't delete their pidfiles when they exit.
	rm -f $PIDFILE
	return "$RETVAL"
}

#
# Function that sends a SIGHUP to the daemon/service
#
do_reload() {
	#
	# If the daemon can reload its configuration without
	# restarting (for example, when it is sent a SIGHUP),
	# then implement that here.
	#
	start-stop-daemon --stop --signal 1 --quiet --pidfile $PIDFILE --name $(basename $DAEMON)
	return 0
}

case "$1" in
start)
	log_daemon_msg "Starting $DESC " "$NAME"
	do_start
	case "$?" in
		0|1) log_end_msg 0 ;;
		2) log_end_msg 1 ;;
	esac
;;
stop)
	log_daemon_msg "Stopping $DESC" "$NAME"
	do_stop
	case "$?" in
		0|1) log_end_msg 0 ;;
		2) log_end_msg 1 ;;
	esac
;;
status)
	status_of_proc "$DAEMON" "$NAME" && exit 0 || exit $?
;;
restart|force-reload)
	log_daemon_msg "Restarting $DESC" "$NAME"
	do_stop
	case "$?" in
	0|1)
		do_start
		case "$?" in
			0) log_end_msg 0 ;;
			1) log_end_msg 1 ;; # Old process is still running
			*) log_end_msg 1 ;; # Failed to start
		esac
	;;
	*)
		# Failed to stop
		log_end_msg 1
	;;
	esac
;;
*)
	echo "Usage: $SCRIPTNAME {start|stop|status|restart|force-reload}" >&2
	exit 3
	;;
esac

exit 0
